#!/usr/bin/python

from ansible.module_utils.basic import AnsibleModule
import json

from ansible.module_utils.am2cm_commons.cdp_cluster import CDPCluster


def run_module():
    module_args = dict(
        cm_configuration=dict(type='dict', required=True),
        service_name=dict(type='str', required=True)
    )

    result = dict(
        changed=False,
        original_message='',
        message=''
    )

    module = AnsibleModule(
        argument_spec=module_args,
        supports_check_mode=True
    )
    result['original_message'] = json.dumps(module.params)
    # ####################################################################
    # ####################################################################
    cluster = CDPCluster(
        hostname=module.params['cm_configuration']['cloudera_manager_hostname'],
        port=module.params['cm_configuration']['cloudera_manager_port'],
        is_https=(module.params['cm_configuration']['cloudera_manager_protocol'] == 'https'),
        verify_ssl=False,
        username=module.params['cm_configuration']['cloudera_manager_admin_username'],
        password=module.params['cm_configuration']['cloudera_manager_admin_password'],
        cluster_name=module.params['cm_configuration']['cluster_name'])

    # if we got this far, then the configuration has been found and needs to be updated
    result['changed'], result['message'] = cluster.get_hostnames_belonging_to_service(module.params['service_name'])

    if result['changed']:
        module.exit_json(**result)
    else:
        module.fail_json(msg="Exception when trying to get hostnames belonging to service", **result)


def main():
    run_module()


if __name__ == '__main__':
    main()
